package me.eax.scalachart

import scalax.chart._
import scalax.chart.Charting._
import java.io._

object Application extends App {
  val defaultChartSize = (512, 384)
  def createSimpleXYLineChart {
    val dataset = Seq((1,2),(2,4),(3,6),(4,8))
    val chart = XYLineChart(
                  dataset.toXYSeriesCollection("f(x)"),
                  title = "XYLineChart Simple Example",
                  domainAxisLabel = "x axis description",
                  rangeAxisLabel = "y axis description"
                )
    // chart.show
    chart.saveAsPNG(new File("./simpleXYLineChart.png"), defaultChartSize)
  }

  def createXYLineChart {
    val dataset = Seq(
                    ("x*x - 2*x", for(x <- -3.0 to 8.0 by 1.0) yield (x, x*x - 2 * x)),
                    ("3 * x", for(x <- 1.0 to 10.0 by 0.1) yield (x, 3 * x))
                  )
    val chart = XYLineChart(
                  dataset.toXYSeriesCollection,
                  title = "XYLineChart Example",
                  domainAxisLabel = "время, с",
                  rangeAxisLabel = "скорость, м/c"
                )
    chart.saveAsPNG(new File("./xyLineChart.png"), defaultChartSize)
  }

  val categoryDatasetExample = Map(
        "январь" -> Map("заработано" -> 2, "потрачено" -> 4),
        "февраль" -> Map("заработано" -> 4, "потрачено" -> 5),
        "март" -> Map("заработано" -> 8, "потрачено" -> 6),
        "апрель" -> Map("заработано" -> 16, "потрачено" -> 7)
      ).toCategoryDataset

  def createLineChart {
    val chart = LineChart(
                  categoryDatasetExample,
                  title = "LineChart Example",
                  domainAxisLabel = "месяц",
                  rangeAxisLabel = "млн рублей"
                )
    chart.saveAsPNG(new File("./lineChart.png"), defaultChartSize)
  }

  def createPieChart {
    val dataset = Map(
        "Erlang" -> 33.3,
        "Scala" -> 33.3,
        "Clojure" -> 13.4,
        "Haskell" -> 10.0,
        "OCaml" -> 10.0
      )
    val chart = PieChart.threeDimensional(
                  dataset.toPieDataset,
                  legend = false,
                  title = """|Результаты опроса
                             |"Ваш любимый язык программирования"
                             |""".stripMargin
                )
    chart.saveAsPNG(new File("./pieChart.png"), defaultChartSize)
  }

  def createSimpleBarChart {
    val dataset = Map("alpha" -> 123.45, "beta" -> 678.9)  
    val chart = BarChart(
                  dataset.toCategoryDataset,
                  title = "Simple Bar Chart Example"
                )
    chart.saveAsPNG(new File("./simpleBarChart.png"), defaultChartSize)
  }

  def createBarChart {
    val chart = BarChart(
                  categoryDatasetExample,
                  title = "Bar Chart Example"
                )
    chart.saveAsPNG(new File("./barChart.png"), defaultChartSize)
  }


  createSimpleXYLineChart
  createXYLineChart
  createLineChart
  createPieChart
  createSimpleBarChart
  createBarChart
}
